summaryrefslogtreecommitdiffstats
path: root/src/classdef.h
diff options
context:
space:
mode:
authorDimitri van Heesch <dimitri@stack.nl>2013-04-02 19:27:49 (GMT)
committerDimitri van Heesch <dimitri@stack.nl>2013-04-02 19:27:49 (GMT)
commitebf4b3641c9149eaf4468aa8df64e1c7517e5f0c (patch)
tree23804fcf753b3487b9a1ea28d4d28b71fa4ae208 /src/classdef.h
parentdeaa34e0c1d990f37fe00e465ac7a22f705904f0 (diff)
downloadDoxygen-ebf4b3641c9149eaf4468aa8df64e1c7517e5f0c.zip
Doxygen-ebf4b3641c9149eaf4468aa8df64e1c7517e5f0c.tar.gz
Doxygen-ebf4b3641c9149eaf4468aa8df64e1c7517e5f0c.tar.bz2
Release-1.8.3.1-20130402
Diffstat (limited to 'src/classdef.h')
-rw-r--r--src/classdef.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/src/classdef.h b/src/classdef.h
index 9db5cae..f4d5962 100644
--- a/src/classdef.h
+++ b/src/classdef.h
@@ -48,7 +48,8 @@ class ArgumentList;
/** A class representing of a compound symbol.
*
* A compound can be a class, struct, union, interface, or exception.
* \note This class should be renamed to CompoundDef
*/
class ClassDef : public Definition
@@ -61,7 +62,9 @@ class ClassDef : public Definition
Interface, //=Entry::INTERFACE_SEC,
Protocol, //=Entry::PROTOCOL_SEC,
Category, //=Entry::CATEGORY_SEC,
- Exception //=Entry::EXCEPTION_SEC
+ Exception, //=Entry::EXCEPTION_SEC
+ Service, //=Entry::CLASS_SEC
+ Singleton, //=Entry::CLASS_SEC
};
/** Creates a new compound definition.
@@ -256,6 +259,9 @@ class ClassDef : public Definition
/** Returns TRUE if this class is marked as sealed */
bool isSealed() const;
+ /** Returns TRUE if this class is marked as published */
+ bool isPublished() const;
+
/** Returns TRUE if this class represents an Objective-C 2.0 extension (nameless category) */
bool isExtension() const;
@@ -320,7 +326,7 @@ class ClassDef : public Definition
void setIsStatic(bool b);
void setCompoundType(CompoundType t);
void setClassName(const char *name);
- void setClassSpecifier(int spec);
+ void setClassSpecifier(uint64 spec);
void setTemplateArguments(ArgumentList *al);
void setTemplateBaseClassNames(QDict<int> *templateNames);
@@ -48,7 +48,8 @@ class ArgumentList;
/** A class representing of a compound symbol.
*
- * A compound can be a class, struct, union, interface, or exception.
+ * A compound can be a class, struct, union, interface, service, singleton,
+ * or exception.
* \note This class should be renamed to CompoundDef
*/